@@ -335,10 +335,10 @@ def recommend_video( prefname="" ):
         if len(recomvid)==0:
             print("X... config WANTS the camera",prefname)
             print("X... NOT FOUND")
-    print("D... recommending:",recomvid)
-    print("i... recommending:",recomvid)
-    print("i... recommending:",recomvid)
-    print("i... recommending:",recomvid)
+    # print("D... recommending:",recomvid)
+    # print("i... recommending:",recomvid)
+    # print("i... recommending:",recomvid)
+    # print("i... recommending:",recomvid)
     print("i... recommending:",recomvid)
 
     #resolutions = get_resolutions( recomvid[0] )
