@@ -199,14 +199,15 @@ setInterval(doDate, 200);
 </table>
 
 <hr>
-      <button style="width:4%" name="speedx" value="SPEEDX">dX</button>
+      <button style="width:3%" name="speedx" value="SPEEDX">dX</button>
     <input type = "text" name = "inputx"  size="5" />
-      <button style="width:4%" name="speedy" value="SPEEDY">dY</button>
+      <button style="width:3%" name="speedy" value="SPEEDY">dY</button>
     <input type = "text" name = "inputy" size="5" />
 
-      <button style="width:7%" name="restart_translate" value="RESTART_TRANSLATE">restart</button>
-      <button style="width:7%" name="zero_translate" value="ZERO_TRANSLATE">zero</button>
-      <button style="width:7%" name="accum" value="ACCUM">Accum</button>
+      <button style="width:6%" name="restart_translate" value="RESTART_TRANSLATE">restart</button>
+      <button style="width:4%" name="zero_translatex" value="ZERO_TRANSLATEX">zeroX</button>
+      <button style="width:4%" name="zero_translatex" value="ZERO_TRANSLATEX">zeroY</button>
+      <button style="width:5%" name="accum" value="ACCUM">Accum</button>
       &nbsp; &nbsp;&nbsp; <input type = "text" name = "accumtxt" size="6" />
 <hr>
       <button style="width:6%" name="gamma2" value="GAMMA2">gm x2</button>
@@ -307,9 +308,9 @@ def cross():
         if request.form.get('restart_translate') == 'RESTART_TRANSLATE':
             mmwrite(f"restart_translate True" )
 
-        if request.form.get('zero_translate') == 'ZERO_TRANSLATE':
+        if request.form.get('zero_translatex') == 'ZERO_TRANSLATEX':
             mmwrite(f"speedx {0}" )
-            time.sleep(0.2) #================ PROBLEM FOR SLOW
+        if request.form.get('zero_translatey') == 'ZERO_TRANSLATEY':
             mmwrite(f"speedy {0}" )
 
         if request.form.get('gamma2') == 'GAMMA2':
